@@ -2,15 +2,15 @@
 # -*- coding: utf-8 -*-
 
 import os
+import json
 import gettext
 from functools import wraps
 from jinja2 import Environment
 from jinja2 import FileSystemLoader
 from jinja2 import TemplateNotFound
 from bottle import JSONPlugin as JsonPlugin
-from lib.config import Config
-
-
+from config import Config
+from bottle import request, response
 
 
 class Jinja2Plugin(object):
@@ -24,7 +24,8 @@ class Jinja2Plugin(object):
         if 'env' not in self.__dict__:
             self.config = Config.get_instance()
             basepath = os.path.join(self.config.apppath, 'bundles')
-            bundels = [name for name in os.listdir(basepath) if os.path.isdir(os.path.join(basepath, name))]
+            bundels = [name for name in os.listdir(
+                basepath) if os.path.isdir(os.path.join(basepath, name))]
             views = []
 
             for bundle in bundels:
@@ -35,10 +36,10 @@ class Jinja2Plugin(object):
             if 'views' in bundels:
                 views.append(os.path.join(basepath, 'views'))
 
-            self.env = Environment(loader=FileSystemLoader(views, encoding='utf-8'), extensions=['jinja2.ext.i18n'])
+            self.env = Environment(loader=FileSystemLoader(
+                views, encoding='utf-8'), extensions=['jinja2.ext.i18n'])
             self.env.install_gettext_translations(gettext.NullTranslations())
 
-
     def apply(self, callback, route):
         @wraps(callback)
         def wrapper(*args, **kwargs):
@@ -52,7 +53,8 @@ class Jinja2Plugin(object):
             bundle = callback.__module__.split('.')[-3]
             controller = callback.__module__.split('.')[-1]
             action = callback.__name__
-            template = os.path.join(bundle, controller, '.'.join([action, 'html']))
+            template = os.path.join(
+                bundle, controller, '.'.join([action, 'html']))
             try:
                 tpl = self.env.get_template(template)
             except TemplateNotFound:
@@ -62,10 +64,31 @@ class Jinja2Plugin(object):
 
         return wrapper
 
+    def setup(self, app):
+        pass
+
+    def close(self):
+        pass
+
+
+class JsonPlugin(object):
+    name = 'json'
+    api = 2
+
+    def apply(self, callback, route):
+        @wraps(callback)
+        def wrapper(*args, **kwargs):
+            if self.name in route.skiplist:
+                return callback(*args, **kwargs)
+
+            data = callback(*args, **kwargs)
+            response.set_header('Content-Type', 'application/json')
+            return json.dumps(data)
+
+        return wrapper
 
     def setup(self, app):
         pass
 
-
     def close(self):
         pass
